Class: Aws::LookoutforVision::Types::Anomaly
- Inherits:
-
Struct
- Object
- Struct
- Aws::LookoutforVision::Types::Anomaly
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lookoutforvision/types.rb
Overview
Information about an anomaly type found on an image by an image segmentation model. For more information, see DetectAnomalies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of an anomaly type found in an image.
-
#pixel_anomaly ⇒ Types::PixelAnomaly
Information about the pixel mask that covers an anomaly type.
Instance Attribute Details
#name ⇒ String
The name of an anomaly type found in an image. Name maps to an
anomaly type in the training dataset, apart from the anomaly type
background. The service automatically inserts the background
anomaly type into the response from DetectAnomalies.
42 43 44 45 46 47 |
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 42 class Anomaly < Struct.new( :name, :pixel_anomaly) SENSITIVE = [] include Aws::Structure end |
#pixel_anomaly ⇒ Types::PixelAnomaly
Information about the pixel mask that covers an anomaly type.
42 43 44 45 46 47 |
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 42 class Anomaly < Struct.new( :name, :pixel_anomaly) SENSITIVE = [] include Aws::Structure end |