Class: Aws::LookoutforVision::Types::DeleteDatasetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LookoutforVision::Types::DeleteDatasetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lookoutforvision/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
ClientToken is an idempotency token that ensures a call to
DeleteDatasetcompletes only once. -
#dataset_type ⇒ String
The type of the dataset to delete.
-
#project_name ⇒ String
The name of the project that contains the dataset that you want to delete.
Instance Attribute Details
#client_token ⇒ String
ClientToken is an idempotency token that ensures a call to
DeleteDataset completes only once. You choose the value to pass.
For example, An issue might prevent you from getting a response from
DeleteDataset. In this case, safely retry your call to
DeleteDataset by using the same ClientToken parameter value.
If you don't supply a value for ClientToken, the AWS SDK you are
using inserts a value for you. This prevents retries after a network
error from making multiple deletetion requests. You'll need to
provide your own value for other use cases.
An error occurs if the other input parameters are not the same as in
the first request. Using a different value for ClientToken is
considered a new call to DeleteDataset. An idempotency token is
active for 8 hours.
A suitable default value is auto-generated. You should normally not need to pass this option.
431 432 433 434 435 436 437 |
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 431 class DeleteDatasetRequest < Struct.new( :project_name, :dataset_type, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_type ⇒ String
The type of the dataset to delete. Specify train to delete the
training dataset. Specify test to delete the test dataset. To
delete the dataset in a single dataset project, specify train.
431 432 433 434 435 436 437 |
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 431 class DeleteDatasetRequest < Struct.new( :project_name, :dataset_type, :client_token) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project that contains the dataset that you want to delete.
431 432 433 434 435 436 437 |
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 431 class DeleteDatasetRequest < Struct.new( :project_name, :dataset_type, :client_token) SENSITIVE = [] include Aws::Structure end |