Class: Aws::LookoutforVision::Types::UpdateDatasetEntriesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lookoutforvision/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#changes ⇒ String

The entries to add to the dataset.

Returns:

  • (String)


2038
2039
2040
2041
2042
2043
2044
2045
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 2038

class UpdateDatasetEntriesRequest < Struct.new(
  :project_name,
  :dataset_type,
  :changes,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

ClientToken is an idempotency token that ensures a call to UpdateDatasetEntries completes only once. You choose the value to pass. For example, An issue might prevent you from getting a response from UpdateDatasetEntries. In this case, safely retry your call to UpdateDatasetEntries by using the same ClientToken parameter value.

If you don't supply a value for ClientToken, the AWS SDK you are using inserts a value for you. This prevents retries after a network error from making multiple updates with the same dataset entries. You'll need to provide your own value for other use cases.

An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to UpdateDatasetEntries. An idempotency token is active for 8 hours.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2038
2039
2040
2041
2042
2043
2044
2045
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 2038

class UpdateDatasetEntriesRequest < Struct.new(
  :project_name,
  :dataset_type,
  :changes,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_type ⇒ String

The type of the dataset that you want to update. Specify train to update the training dataset. Specify test to update the test dataset. If you have a single dataset project, specify train.

Returns:

  • (String)


2038
2039
2040
2041
2042
2043
2044
2045
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 2038

class UpdateDatasetEntriesRequest < Struct.new(
  :project_name,
  :dataset_type,
  :changes,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#project_name ⇒ String

The name of the project that contains the dataset that you want to update.

Returns:

  • (String)


2038
2039
2040
2041
2042
2043
2044
2045
# File 'lib/aws-sdk-lookoutforvision/types.rb', line 2038

class UpdateDatasetEntriesRequest < Struct.new(
  :project_name,
  :dataset_type,
  :changes,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end